Estimate a reasonable bandwidth parameter (sigma) for the heat kernel based on a data matrix and the specified quantile of the frequency distribution of distances.
Arguments
- X
A data matrix where samples are rows and features are columns.
- prop
A numeric value representing the quantile of the frequency distribution of distances used to determine the bandwidth parameter. Default is 0.25.
- nsamples
An integer representing the number of samples to draw from the data matrix. Default is 500.
- normalized
A logical value indicating whether to normalize the data. Default is FALSE.