Creates a simple 5x5 factorial design kernel with two nominal factors, useful for testing and demonstration purposes.
Value
A list with kernel matrices and metadata (see design_kernel)
Creates a simple 5x5 factorial design kernel with two nominal factors, useful for testing and demonstration purposes.
A list with kernel matrices and metadata (see design_kernel)