This function retrieves the indices of neighbors of one or more vertices in a given graph or graph-like object.
Value
A list of vertex indices representing the neighbors of the specified vertices. The length of the list is equal to the number of input vertices, and each element in the list contains the neighbor indices for the corresponding input vertex.
Examples
# \donttest{
g <- neighbor_graph(igraph::make_ring(5))
n <- adjoin::neighbors(g, 1)
# }