Compute the Difference of Gaussians for a coordinate matrix
Source:R/spatial_weights.R
difference_of_gauss.RdThis function computes the Difference of Gaussians for a given coordinate matrix using specified sigma values and the number of nearest neighbors.
Arguments
- coord_mat
A numeric matrix representing coordinates
- sigma1
Numeric, the first sigma parameter for the Gaussian smoother (default is 2)
- sigma2
Numeric, the second sigma parameter for the Gaussian smoother (default is sigma1 * 1.6)
- nnk
Integer, the number of nearest neighbors for adjacency (default is 3^(ncol(coord_mat)))